==> apgl-0.5.9.1.tar.gz: apgl-0.5.9.1/apgl/graph/GeneralVertexList.py <==

from apgl.graph.AbstractVertexList import AbstractVertexList
from apgl.util.Parameter import Parameter

class GeneralVertexList(AbstractVertexList):
    """
    A GeneralVertexList is a list of vertices (immutable in size), in which any
    object can label each vertex. The underlying data structure is a dict. 
    """
    def __init__(self, numVertices):
        """
        Create an empty (None) GeneralVertexList with the specified number of features
        for each vertex and number of vertices.
        """
        Parameter.checkInt(numVertices, 0, float('inf'))

        self.V = {}
        
        for i in range(numVertices):
            self.V[i] = None

    def getNumVertices(self):
        """
        Returns the number of vertices contained in this object.
        """
        return len(self.V)

    def getVertices(self, vertexIndices):
        """
        Returns a list of vertices specified by vertexIndices.

        :param vertexIndices: a list of vertex indices.
        :type vertexIndices: :class:`list`
        """
        Parameter.checkList(vertexIndices, Parameter.checkIndex, (0, len(self.V)))

        vertices = []
        for i in vertexIndices:
            vertices.append(self.V[i])

        return vertices

    def setVertex(self, index, value):
        """
        Set a vertex to the corresponding value.

        :param index: the index of the vertex to assign a value.
        :type index: :class:`int`

        :param value: the value to assign to the vertex.
        """
        Parameter.checkIndex(index, 0, len(self.V))

        self.V[index] = value

    def setVertices(self, vertices):
        """
        Set the vertices to the given list of vertices in the given order.

        :param vertices: a set of vertices of the same shape as this object.
        :type vertices: :class:`numpy.ndarray`
        """
        if len(vertices) != len(self.V):
            raise ValueError("Incorrect number of vertices " + str(vertices.shape[0]) + ", expecting " + str(self.V.shape[0]))

        for i in range(len(vertices)):
            self.V[i] = vertices[i]

    def clearVertex(self, index):
        """
        Sets a vertex to None

        :param index: the index of the vertex to assign a value.
        :type index: :class:`int`
        """
        Parameter.checkIndex(index, 0, len(self.V))
        self.V[index] = None

    def getVertex(self, index):
        """
        Returns the value of a vertex.

        :param index: the index of the vertex.
        :type index: :class:`int`
        """
        Parameter.checkIndex(index, 0, len(self.V))
        return self.V[index]

    def __str__(self):
        """
        Returns the string representation of this object.
        """
        return self.V.__str__()

    def copy(self):
        """
        Returns a copy of this object.
        """
        vList = GeneralVertexList(len(self.V))
        vList.setVertices(self.V.values())
        return vList

    def subList(self, indices):
        """
        Returns a subset of this object, indicated by the given indices.
        """
        vList = GeneralVertexList(len(indices))
        vList.setVertices(self.getVertices(indices))

        return vList

    V = None

==> apgl-0.6.1.tar.gz: apgl-0.6.1/apgl/graph/GeneralVertexList.py <==

from apgl.graph.AbstractVertexList import AbstractVertexList
from apgl.util.Parameter import Parameter

class GeneralVertexList(AbstractVertexList):
    """
    A GeneralVertexList is a list of vertices (immutable in size), in which any
    object can label each vertex. The underlying data structure is a dict. 
    """
    def __init__(self, numVertices):
        """
        Create an empty GeneralVertexList with the specified number of features
        for each vertex (initialised as None) and number of vertices.

        :param numVertices: The number of vertices.
        :type numVertices: :class:`int`
        """
        Parameter.checkInt(numVertices, 0, float('inf'))

        self.V = {}
        
        for i in range(numVertices):
            self.V[i] = None

    def getNumVertices(self):
        """
        Returns the number of vertices contained in this object.
        """
        return len(self.V)

    def getVertices(self, vertexIndices):
        """
        Returns a list of vertices specified by vertexIndices.

        :param vertexIndices: a list of vertex indices.
        :type vertexIndices: :class:`list`
        """
        Parameter.checkList(vertexIndices, Parameter.checkIndex, (0, len(self.V)))

        vertices = []
        for i in vertexIndices:
            vertices.append(self.V[i])

        return vertices

    def setVertex(self, index, value):
        """
        Set a vertex to the corresponding value.

        :param index: the index of the vertex to assign a value.
        :type index: :class:`int`

        :param value: the value to assign to the vertex.
        """
        Parameter.checkIndex(index, 0, len(self.V))

        self.V[index] = value

    def setVertices(self, vertices):
        """
        Set the vertices to the given list of vertices.

        :param vertices: a set of vertices of the same shape as this object.
        :type vertices: :class:`list`
        """
        if len(vertices) != len(self.V):
            raise ValueError("Incorrect number of vertices " + str(vertices.shape[0]) + ", expecting " + str(self.V.shape[0]))

        for i in range(len(vertices)):
            self.V[i] = vertices[i]

    def clearVertex(self, index):
        """
        Sets a vertex to None

        :param index: the index of the vertex to assign a value.
        :type index: :class:`int`
        """
        Parameter.checkIndex(index, 0, len(self.V))
        self.V[index] = None

    def getVertex(self, index):
        """
        Returns the value of a vertex.

        :param index: the index of the vertex.
        :type index: :class:`int`
        """
        Parameter.checkIndex(index, 0, len(self.V))
        return self.V[index]

    def __str__(self):
        """
        Returns the string representation of this object.
        """
        return self.V.__str__()

    def copy(self):
        """
        Returns a copy of this object.
        """
        vList = GeneralVertexList(len(self.V))
        vList.setVertices(self.V.values())
        return vList

    def subList(self, indices):
        """
        Returns a subset of this object, indicated by the given indices.
        """
        vList = GeneralVertexList(len(indices))
        vList.setVertices(self.getVertices(indices))

        return vList

    V = None
